permissionHandler.PermissionHandler

|  | ## Cheshire3 Object Model: Class PermissionHandler

Module permissionHandler :: Class PermissionHandler

## Class PermissionHandler
source code

Instance Methods

__init__(self, node, parent)
_walkNode(self, node)

Class Variables

actionIdentifier |
codeText |
hasPermission |

Method Details

### __init__(self, node, parent) (Constructor) | source code

### _walkNode(self, node) | source code

Class Variable Details

    ### actionIdentifier Value:
        ''

    ### codeText Value:
        []

    ### hasPermission Value:
        None